==> jc-1.4.0.tar.gz: soot/javaToJimple/TypeListBuilder.h <==
// public class soot.javaToJimple.TypeListBuilder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 938428ed7347e804 soot_javaToJimple_TypeListBuilder

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_TypeListBuilder_H_
#define _JC_soot_javaToJimple_TypeListBuilder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_TypeListBuilder$sub_refs	_jc_soot_javaToJimple_TypeListBuilder$sub_refs;
typedef struct _jc_soot_javaToJimple_TypeListBuilder$sub_nonrefs	_jc_soot_javaToJimple_TypeListBuilder$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_TypeListBuilder$refs	_jc_soot_javaToJimple_TypeListBuilder$refs;
typedef struct _jc_soot_javaToJimple_TypeListBuilder$nonrefs	_jc_soot_javaToJimple_TypeListBuilder$nonrefs;
typedef struct _jc_soot_javaToJimple_TypeListBuilder$object	_jc_soot_javaToJimple_TypeListBuilder$object;

typedef const struct _jc_soot_javaToJimple_TypeListBuilder$vmethods	_jc_soot_javaToJimple_TypeListBuilder$vmethods;
typedef const struct _jc_soot_javaToJimple_TypeListBuilder$vtable	_jc_soot_javaToJimple_TypeListBuilder$vtable;
typedef const struct _jc_soot_javaToJimple_TypeListBuilder$vtype	_jc_soot_javaToJimple_TypeListBuilder$vtype;

// Constructors
extern void _jc_soot_javaToJimple_TypeListBuilder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_TypeListBuilder$object *);

// Virtual methods
extern struct _jc_java_util_HashSet$object *_jc_soot_javaToJimple_TypeListBuilder$method$getList$abe91cab12ed1c8b(_jc_env *, struct _jc_soot_javaToJimple_TypeListBuilder$object *);
extern struct _jc_object *_jc_soot_javaToJimple_TypeListBuilder$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_TypeListBuilder$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_TypeListBuilder$method_info$getList$abe91cab12ed1c8b;
extern _jc_method _jc_soot_javaToJimple_TypeListBuilder$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_TypeListBuilder$vmethods {
	struct _jc_java_util_HashSet$object	*(*getList$abe91cab12ed1c8b)(_jc_env *, struct _jc_soot_javaToJimple_TypeListBuilder$object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_TypeListBuilder$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_soot_javaToJimple_TypeListBuilder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_TypeListBuilder$vmethods	soot_javaToJimple_TypeListBuilder;
};

// Vtype
struct _jc_soot_javaToJimple_TypeListBuilder$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_TypeListBuilder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_TypeListBuilder$sub_refs {
	struct _jc_java_util_HashSet$object	*list;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_TypeListBuilder$refs {
    _jc_soot_javaToJimple_TypeListBuilder$sub_refs	soot_javaToJimple_TypeListBuilder;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_TypeListBuilder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_TypeListBuilder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_TypeListBuilder$sub_nonrefs	soot_javaToJimple_TypeListBuilder;
};

// Object instance structure
struct _jc_soot_javaToJimple_TypeListBuilder$object {
	_jc_soot_javaToJimple_TypeListBuilder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_TypeListBuilder$vtype	*vtype;
	_jc_soot_javaToJimple_TypeListBuilder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_TypeListBuilder$vtype _jc_soot_javaToJimple_TypeListBuilder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_TypeListBuilder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_TypeListBuilder$class_object;

#endif	/* _JC_soot_javaToJimple_TypeListBuilder_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/TypeListBuilder.h <==
// public class soot.javaToJimple.TypeListBuilder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 938428ed7347e804 soot_javaToJimple_TypeListBuilder

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_TypeListBuilder_H_
#define _JC_soot_javaToJimple_TypeListBuilder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_TypeListBuilder$sub_refs	_jc_soot_javaToJimple_TypeListBuilder$sub_refs;
typedef struct _jc_soot_javaToJimple_TypeListBuilder$sub_nonrefs	_jc_soot_javaToJimple_TypeListBuilder$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_TypeListBuilder$refs	_jc_soot_javaToJimple_TypeListBuilder$refs;
typedef struct _jc_soot_javaToJimple_TypeListBuilder$nonrefs	_jc_soot_javaToJimple_TypeListBuilder$nonrefs;
typedef struct _jc_soot_javaToJimple_TypeListBuilder$object	_jc_soot_javaToJimple_TypeListBuilder$object;

typedef const struct _jc_soot_javaToJimple_TypeListBuilder$vmethods	_jc_soot_javaToJimple_TypeListBuilder$vmethods;
typedef const struct _jc_soot_javaToJimple_TypeListBuilder$vtable	_jc_soot_javaToJimple_TypeListBuilder$vtable;
typedef const struct _jc_soot_javaToJimple_TypeListBuilder$vtype	_jc_soot_javaToJimple_TypeListBuilder$vtype;

// Constructors
extern void _jc_soot_javaToJimple_TypeListBuilder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_TypeListBuilder$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_HashSet$object *_jc_soot_javaToJimple_TypeListBuilder$method$getList$abe91cab12ed1c8b(_jc_env *, struct _jc_soot_javaToJimple_TypeListBuilder$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_TypeListBuilder$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_TypeListBuilder$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_TypeListBuilder$method_info$getList$abe91cab12ed1c8b;
extern _jc_method _jc_soot_javaToJimple_TypeListBuilder$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_TypeListBuilder$vmethods {
	struct _jc_java_util_HashSet$object	*(*getList$abe91cab12ed1c8b)(_jc_env *, struct _jc_soot_javaToJimple_TypeListBuilder$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_TypeListBuilder$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_TypeListBuilder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_TypeListBuilder$vmethods	soot_javaToJimple_TypeListBuilder;
};

// Vtype
struct _jc_soot_javaToJimple_TypeListBuilder$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_TypeListBuilder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_TypeListBuilder$sub_refs {
	struct _jc_java_util_HashSet$object	*list;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_TypeListBuilder$refs {
    _jc_soot_javaToJimple_TypeListBuilder$sub_refs	soot_javaToJimple_TypeListBuilder;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_TypeListBuilder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_TypeListBuilder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_TypeListBuilder$sub_nonrefs	soot_javaToJimple_TypeListBuilder;
};

// Object instance structure
struct _jc_soot_javaToJimple_TypeListBuilder$object {
	_jc_soot_javaToJimple_TypeListBuilder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_TypeListBuilder$vtype	*vtype;
	_jc_soot_javaToJimple_TypeListBuilder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_TypeListBuilder$vtype _jc_soot_javaToJimple_TypeListBuilder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_TypeListBuilder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_TypeListBuilder$class_object;

#endif	/* _JC_soot_javaToJimple_TypeListBuilder_H_ */
